==> foundation-stories-0.19.0.tgz: package/stories/component-theme/demo/ComponentTheme.stories.tsx <==
import { Story } from '@ladle/react';
import React from 'react';
import styled, { ThemeProvider } from 'styled-components';

import {
  getDefaultValue,
  globalTheme,
  overrideTheme,
} from '@clds/component-theme';

import { GlobalMixins } from './components/GlobalMixins';
import { ThemeMixins } from './components/ThemeMixins';
import { theme as themeMixinsTheme } from './components/ThemeMixins.theme';
import { ThemeMixinsWithCombine } from './components/ThemeMixinsWithCombine';
import { ThemeMixinsWithCombineVariant } from './components/ThemeMixinsWithCombineVariant';

export default {
  title: 'Component Theme',
};

const Container = styled.div`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  background-color: ${globalTheme.palette.background};
  padding: ${globalTheme.spacing.md};
`;

const Intro = styled.p`
  color: ${globalTheme.palette.contrastLow};
`;

const Code = styled(({ children, ...rest }) => (
  <pre {...rest}>
    <code lang="javascript">{children}</code>
  </pre>
))`
  max-width: 100%;
`;

export const GlobalMixinsDemo = () => (
  <Container>
    <Intro>
      This example shows basic usage of global theme mixins. You cannot override
      definitions for particular component
    </Intro>
    <GlobalMixins>Only global mixins</GlobalMixins>
  </Container>
);

export const ThemeMixinsDemo: Story<{
  buttonColor: string;
  iconColor: string;
}> = ({ buttonColor, iconColor }) => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const newTheme = (baseTheme: any) => ({
    ...baseTheme,
    components: {
      ...baseTheme.components,
      ...overrideTheme(themeMixinsTheme, {
        button: {
          background: { color: buttonColor },
          icon: { color: iconColor },
        },
      }),
    },
  });

  // TODO: Uncomment after full Design System migration
  return (
    <ThemeProvider theme={newTheme}>
      <Container>
        <Intro>
          This example shows basic usage of mixins defined in separate theme.
          You can override that definitions via theme context.
        </Intro>
        <ThemeMixins>Global mixins moved to theme</ThemeMixins>
        <Intro>
          Use storybook controls panel to override some colors of this component
          theme
        </Intro>
        <Intro as="div">
          Source theme
          <Code>{themeMixinsTheme.toString()}</Code>
        </Intro>
      </Container>
    </ThemeProvider>
  );
};

ThemeMixinsDemo.argTypes = {
  buttonColor: {
    control: {
      type: 'color',
    },
  },
  iconColor: {
    control: {
      type: 'color',
    },
  },
};

ThemeMixinsDemo.args = {
  buttonColor: getDefaultValue(globalTheme.palette.primary),
  iconColor: getDefaultValue(globalTheme.palette.contrastInvert),
};

// TODO: Uncomment after full Design System migration
export const ThemeMixinsWithCombineDemo = () => (
  <Container>
    <Intro>
      You can derive from global and component definitions using combineValues.
      combineValues accepts all kind of mixins: global, theme mixins.
    </Intro>
    <Intro>
      Please note that every node of component theme (leafs, intermediate
      parents and roots) are supported. For parents - combineValues will return
      a corresponding tree of values.
    </Intro>
    <Intro>combineValues with theme and global mixins</Intro>
    <Code>
      box-shadow: 0 2px 5px 0 $&#123; combineValues(theme.background,
      mixins.palette.primary, (background, primary) =&gt; mix(0.5, background,
      primary))&#125;;
    </Code>
    <Intro>combineValues on parent nodes </Intro>
    <Code>
      background-color: $&#123; combineValues(theme.button, (button, props)
      =&gt; (props.selected ? button.background.color :
      button.icon.color))&#125;;
    </Code>
    <Code>
      color: $&#123; combineValues(theme, (theme, props) =&gt; (props.selected ?
      theme.button.icon.color : theme.text.color))&#125;;
    </Code>
    <ThemeMixinsWithCombine>combineValues with mixins</ThemeMixinsWithCombine>
    <ThemeMixinsWithCombine selected>
      combineValues with mixins - selected
    </ThemeMixinsWithCombine>
  </Container>
);

// TODO: Uncomment after full Design System migration
export const ThemeMixinsWithCombineVariantDemo = () => (
  <Container>
    <Intro>
      You also can make a variant selector based on props that will return
      particular subtree of theme. In this example we have a variant:
    </Intro>
    <Code>
      const variant = createVariant((props: Props) =&gt;
      theme[props.shape][props.type]);
    </Code>
    You can call variant with a selector to easily create derived mixin:
    <Code>background-color: $&#123;variant(t =&gt; t.background)&#125;;</Code>
    <ThemeMixinsWithCombineVariant shape="solid" type="primary">
      Solid primary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="solid" type="secondary">
      Solid secondary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="pill" type="primary">
      Pill primary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="pill" type="secondary">
      Pill secondary
    </ThemeMixinsWithCombineVariant>
  </Container>
);

==> foundation-stories-0.41.1.tgz: package/stories/component-theme/demo/ComponentTheme.stories.tsx <==
import { Story } from '@ladle/react';
import React from 'react';
import styled, { ThemeProvider } from 'styled-components';

import {
  getDefaultValue,
  globalTheme,
  overrideTheme,
} from '@clds/component-theme';

import { GlobalMixins } from './components/GlobalMixins';
import { ThemeMixins } from './components/ThemeMixins';
import { theme as themeMixinsTheme } from './components/ThemeMixins.theme';
import { ThemeMixinsWithCombine } from './components/ThemeMixinsWithCombine';
import { ThemeMixinsWithCombineVariant } from './components/ThemeMixinsWithCombineVariant';

export default {
  title: 'Component Theme',
};

const Container = styled.div`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  background-color: ${globalTheme.palette.background};
  padding: ${globalTheme.spacing.md};
`;

const Intro = styled.p`
  color: ${globalTheme.palette.contrastLow};
`;

const Code = styled(({ children, ...rest }) => (
  <pre {...rest}>
    <code lang="javascript">{children}</code>
  </pre>
))`
  max-width: 100%;
`;

export const GlobalMixinsDemo = () => (
  <Container>
    <Intro>
      This example shows basic usage of global theme mixins. You cannot override
      definitions for particular component
    </Intro>
    <GlobalMixins>Only global mixins</GlobalMixins>
  </Container>
);

export const ThemeMixinsDemo: Story<{
  buttonColor: string;
  iconColor: string;
}> = ({ buttonColor, iconColor }) => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const newTheme = (baseTheme: any) => ({
    ...baseTheme,
    components: {
      ...baseTheme.components,
      ...overrideTheme(themeMixinsTheme, {
        button: {
          background: { color: buttonColor },
          icon: { color: iconColor },
        },
      }),
    },
  });

  // TODO: Uncomment after full Design System migration
  return (
    <ThemeProvider theme={newTheme}>
      <Container>
        <Intro>
          This example shows basic usage of mixins defined in separate theme.
          You can override that definitions via theme context.
        </Intro>
        <ThemeMixins>Global mixins moved to theme</ThemeMixins>
        <Intro>
          Use storybook controls panel to override some colors of this component
          theme
        </Intro>
        <Intro as="div" data-chromatic="ignore">
          Source theme
          <Code>{themeMixinsTheme.toString()}</Code>
        </Intro>
      </Container>
    </ThemeProvider>
  );
};

ThemeMixinsDemo.argTypes = {
  buttonColor: {
    control: {
      type: 'color',
    },
  },
  iconColor: {
    control: {
      type: 'color',
    },
  },
};

ThemeMixinsDemo.args = {
  buttonColor: getDefaultValue(globalTheme.palette.primary),
  iconColor: getDefaultValue(globalTheme.palette.contrastInvert),
};

// TODO: Uncomment after full Design System migration
export const ThemeMixinsWithCombineDemo = () => (
  <Container>
    <Intro>
      You can derive from global and component definitions using combineValues.
      combineValues accepts all kind of mixins: global, theme mixins.
    </Intro>
    <Intro>
      Please note that every node of component theme (leafs, intermediate
      parents and roots) are supported. For parents - combineValues will return
      a corresponding tree of values.
    </Intro>
    <Intro>combineValues with theme and global mixins</Intro>
    <Code data-chromatic="ignore">
      box-shadow: 0 2px 5px 0 $&#123; combineValues(theme.background,
      mixins.palette.primary, (background, primary) =&gt; mix(0.5, background,
      primary))&#125;;
    </Code>
    <Intro data-chromatic="ignore">combineValues on parent nodes </Intro>
    <Code data-chromatic="ignore">
      background-color: $&#123; combineValues(theme.button, (button, props)
      =&gt; (props.selected ? button.background.color :
      button.icon.color))&#125;;
    </Code>
    <Code data-chromatic="ignore">
      color: $&#123; combineValues(theme, (theme, props) =&gt; (props.selected ?
      theme.button.icon.color : theme.text.color))&#125;;
    </Code>
    <ThemeMixinsWithCombine data-chromatic="ignore">
      combineValues with mixins
    </ThemeMixinsWithCombine>
    <ThemeMixinsWithCombine selected data-chromatic="ignore">
      combineValues with mixins - selected
    </ThemeMixinsWithCombine>
  </Container>
);

// TODO: Uncomment after full Design System migration
export const ThemeMixinsWithCombineVariantDemo = () => (
  <Container data-chromatic="ignore">
    <Intro>
      You also can make a variant selector based on props that will return
      particular subtree of theme. In this example we have a variant:
    </Intro>
    <Code>
      const variant = createVariant((props: Props) =&gt;
      theme[props.shape][props.type]);
    </Code>
    You can call variant with a selector to easily create derived mixin:
    <Code>background-color: $&#123;variant(t =&gt; t.background)&#125;; </Code>
    <ThemeMixinsWithCombineVariant shape="solid" type="primary">
      Solid primary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="solid" type="secondary">
      Solid secondary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="pill" type="primary">
      Pill primary
    </ThemeMixinsWithCombineVariant>
    <ThemeMixinsWithCombineVariant shape="pill" type="secondary">
      Pill secondary
    </ThemeMixinsWithCombineVariant>
  </Container>
);
